/*
 * This file is part of the rtap localisation project.
 */

#ifndef _RTAPAGGREGATE_H
#define _RTAPAGGREGATE_H


#include "../../librtaputil/rtaputil.h"


#define AGGREGATE_TIMEOUT 1500 // Timeout d'agrégation (en millisecondes)
#define KEEP_TIMEOUT 3000 // Temps que l'on conserve les données dans la liste (en millisecondes)
#define CHECK_INTERVAL 500000 // Temps entre deux vérifications de la liste (en micro-secondes)


/* Arguments du programme */
#define ARGC 2
#define ARGV_OUTPUT_FILE 1


/* Codes d'erreur */
#define ERR_NO_MESSAGE_RECEIVED 1 // Erreur lors de la lecture sur la socket
#define ERR_CREATING_SOCKET 2 // Erreur lors de la création de la socket d'écoute
#define ERR_BAD_USAGE 3 // Mauvais appel au programme


/* Liste chaînée des informations concernant un couple MAC / séquence */
typedef struct _couple_info_list
{
  unsigned char ap_mac_addr_bytes[6] ; // Adresse MAC de l'AP émetteur de l'info en octets
  unsigned char antenna_signal_dbm ; // Puissance du signal reçu par l'AP du mobile
  struct _couple_info_list *next ;
} couple_info_list ;


/* Liste chaînée des couples MAC / séquence */
typedef struct _couple_list
{
  /* Numéro de séquence de la demande de localisation du mobile */
  unsigned char mobile_mac_addr_bytes[6] ; // Adresse MAC du mobile en octets
  struct timeval request_time ; //  Heure de la demande sur le mobile

  /* Données pour la calibration */
  float x_position ;
  float y_position ;
  float z_position ;
  DIRECTION direction ; // Orientation de la demande de localisation

  /* Autres données */
  struct timeval start_time ; // Heure d'arrivée du premier paquet du couple sur le serveur d'agrégation
  couple_info_list *info ; // Liste des informations pour ce couple
  struct _couple_list *next ;
} couple_list ;


/* En-têtes de fonctions */
void got_couple_info(couple_list **couples, couple_message message) ;
void free_couple_list(couple_list **couples) ;
void print_couple_list(couple_list *couples) ;
void print_couple_info(couple_info_list *info) ;
void* monitor_couple_list(couple_list **couples) ;
void print_usage(char *prog) ;


#endif
